### Many Packages that help to do data science in different industry, mostly working well on finance
## Data cleaning 
## Data Transformation
## Normalization
## Feature Engineering
## Machine Learning Model